@@ -18,7 +18,7 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: client.c,v 1.69 2007/08/30 15:08:00 evertonm Exp $ */
+/* $Id: client.c,v 1.70 2007/10/18 21:51:43 evertonm Exp $ */
 
 #include <stdio.h>
 #include <sys/types.h>
@@ -383,7 +383,10 @@ static void *on_tcp_duration(oop_source *src, struct timeval tv, void *user)
                   session->tv_start.tv_sec,
                   session->test_duration,
                   session->total_reads,
-                  session->total_writes);
+                  session->total_writes,
+		  &session->min,
+		  &session->max,
+		  1 /* report_min_max = true */);
 
   session->byte_total_recv = 0;
   session->byte_total_sent = 0;
@@ -411,7 +414,10 @@ static void *on_tcp_interval(oop_source *src, struct timeval tv, void *user)
                   session->tv_start.tv_sec,
                   session->test_duration,
                   session->interval_reads,
-                  session->interval_writes);
+                  session->interval_writes,
+		  &session->min,
+		  &session->max,
+		  session->report_partial_min_max);
 
   session->byte_interval_recv = 0;
   session->byte_interval_sent = 0;
@@ -454,6 +460,7 @@ static int greet(int sd)
   opt.sweep_step              = nepim_global.sweep_step;
   opt.write_floor             = nepim_global.server_write_floor;
   opt.write_ceil              = nepim_global.server_write_ceil;
+  opt.report_partial_min_max  = nepim_global.report_partial_min_max;
 
   if (nepim_global.password) {
     opt.password_buf      = (char *) nepim_global.password;
@@ -976,6 +983,7 @@ static void spawn_one_tcp_client(const char *hostport,
       opt.sweep_step              = nepim_global.sweep_step;
       opt.write_floor             = nepim_global.write_floor;
       opt.write_ceil              = nepim_global.write_ceil;
+      opt.report_partial_min_max  = nepim_global.report_partial_min_max;
 
       nepim_pipe_set_add(&pipes, sd, ai->ai_addr, ai->ai_addrlen, &opt);
     }
