@@ -18,7 +18,7 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: common.c,v 1.89 2007/08/30 15:08:00 evertonm Exp $ */
+/* $Id: common.c,v 1.91 2007/10/18 21:51:43 evertonm Exp $ */
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -42,6 +42,8 @@ MA 02110-1301 USA
 const char * const NEPIM_LABEL_PARTIAL      = "prt";
 const char * const NEPIM_LABEL_TOTAL        = "avg";
 const char * const NEPIM_LABEL_TOTAL_BROKEN = "avg(broken)";
+const char * const NEPIM_LABEL_MIN          = "min";
+const char * const NEPIM_LABEL_MAX          = "max";
 
 const char * const NEPIM_MSG_KEEPALIVES_SCHED = "scheduling sending of keepalives";
 const char * const NEPIM_MSG_KEEPALIVES_MISS  = "peer not sending keepalives? (see option -K)";
@@ -51,7 +53,7 @@ static int line = 0;
 
 const char *nepim_version()
 {
-  return "0.42";
+  return "0.43";
 }
 
 static void header(FILE *out, int ident, int udp)
@@ -70,44 +72,107 @@ static void header(FILE *out, int ident, int udp)
   }
 }
 
-static void nepim_dump_stat(FILE *out,
+#define MIN_UPDATE(a, b) { if ((a) < (b)) (b) = (a); }
+#define MAX_UPDATE(a, b) { if ((a) > (b)) (b) = (a); }
+
+static void dump_rates_line(FILE *out,
+			    float kbps_in, float kbps_out,
+			    float read_rate, float write_rate)
+{
+  fprintf(out,
+          " %10.2f %10.2f %8.2f %8.2f", 
+          kbps_in,
+          kbps_out,
+          read_rate,
+          write_rate);
+}
+
+static void dump_ratio(FILE *out, float ratio)
+{
+  char buf[100];
+  int pr;
+
+  pr = snprintf(buf, sizeof buf, "%6.4f", ratio);
+  fprintf(out, " %s", (*buf == '0') ? (buf + 1) : buf);
+}
+
+static void show_rates_line(FILE *out,
+			    const nepim_mark_t *mark,
+			    int udp)
+{
+  dump_rates_line(out,
+		  mark->kbps_in,
+		  mark->kbps_out,
+		  mark->pps_in,
+		  mark->pps_out);
+
+  if (udp) {
+    dump_ratio(out, mark->pkt_loss);
+    dump_ratio(out, mark->pkt_ooo);
+  }
+
+  fprintf(out, "\n");
+}
+
+static void nepim_dump_rates(FILE *out,
                             long long bytes_recv, long long bytes_sent, 
-                            float interval, int reads, int writes)
+                            float interval, int reads, int writes,
+			    nepim_mark_t *min, nepim_mark_t *max)
 {
   float kbps_recv = bytes_recv / (interval * 125); /* 8/1000 = 1/125 */
   float kbps_sent = bytes_sent / (interval * 125); /* 8/1000 = 1/125 */
   float read_rate = reads / interval;
   float write_rate = writes / interval;
 
-  fprintf(out,
-          " %10.2f %10.2f %8.2f %8.2f", 
-          kbps_recv,
-          kbps_sent,
-          read_rate,
-          write_rate);
+  MIN_UPDATE(kbps_recv, min->kbps_in);
+  MIN_UPDATE(kbps_sent, min->kbps_out);
+  MIN_UPDATE(read_rate, min->pps_in);
+  MIN_UPDATE(write_rate, min->pps_out);
+
+  MAX_UPDATE(kbps_recv, max->kbps_in);
+  MAX_UPDATE(kbps_sent, max->kbps_out);
+  MAX_UPDATE(read_rate, max->pps_in);
+  MAX_UPDATE(write_rate, max->pps_out);
+
+  dump_rates_line(out,
+		  kbps_recv,
+		  kbps_sent,
+		  read_rate,
+		  write_rate);
 }
 
 void nepim_pipe_stat(FILE *out, struct timeval now,
 		     const char *label, int sd,
                      long long bytes_recv, long long bytes_sent, 
                      float interval, long sec_start, 
-                     long sec_duration, int reads, int writes)
+                     long sec_duration, int reads, int writes,
+		     nepim_mark_t *min, nepim_mark_t *max,
+		     int report_min_max)
 {
   char buf[100];
   int pr;
+  long ts = sec_duration - (now.tv_sec - sec_start);
 
   pr = snprintf(buf, sizeof buf, "%3d %3s %5ld",
-		sd, label, sec_duration - (now.tv_sec - sec_start));
+		sd, label, ts);
 
   header(out, pr, 0 /* udp=false */);
 
   fprintf(out, buf);
 
-  nepim_dump_stat(out, bytes_recv, bytes_sent, 
-                  interval, reads, writes);
+  nepim_dump_rates(out, bytes_recv, bytes_sent, 
+		   interval, reads, writes,
+		   min, max);
 
   fprintf(out, "\n");
 
+  if (report_min_max) {
+    fprintf(out, "%3d %3s %5ld", sd, NEPIM_LABEL_MIN, ts);
+    show_rates_line(out, min, 0 /* udp=false */);
+    fprintf(out, "%3d %3s %5ld", sd, NEPIM_LABEL_MAX, ts);
+    show_rates_line(out, max, 0 /* udp=false */);
+  }
+
   /* otherwise server won't output stats if out is redirected */
   fflush(out);
 }
@@ -119,22 +184,26 @@ void nepim_slot_stat(FILE *out, struct timeval now,
                      float interval, long sec_start, 
                      long sec_duration, int reads, int writes,
                      uint64_t pkt_expected, uint64_t pkt_lost,
-		     uint64_t pkt_ooo, uint64_t acc_pkt_lost)
+		     uint64_t pkt_ooo, uint64_t acc_pkt_lost,
+		     nepim_mark_t *min, nepim_mark_t *max,
+		     int report_min_max)
 {
   char buf[100];
   int pr;
+  long ts = sec_duration - (now.tv_sec - sec_start);
 
   pr = snprintf(buf, sizeof buf, 
 		"%3d %3d %3d %4s %5ld",
 		sd, local_slot, remote_slot,
-		label, sec_duration - (now.tv_sec - sec_start));
+		label, ts);
 
   header(out, pr, 1 /* udp=true */);
 
   fprintf(out, buf);
 
-  nepim_dump_stat(out, bytes_recv, bytes_sent, 
-                  interval, reads, writes);
+  nepim_dump_rates(out, bytes_recv, bytes_sent, 
+		   interval, reads, writes,
+		   min, max);
 
   {
     float loss_ratio = pkt_lost;
@@ -148,18 +217,21 @@ void nepim_slot_stat(FILE *out, struct timeval now,
     loss_ratio /= pkt_expected;
     ooo_ratio  /= pkt_expected;
 
+    MIN_UPDATE(loss_ratio, min->pkt_loss);
+    MIN_UPDATE(ooo_ratio, min->pkt_ooo);
+
+    MAX_UPDATE(loss_ratio, max->pkt_loss);
+    MAX_UPDATE(ooo_ratio, max->pkt_ooo);
+
 #if 0
     fprintf(out,
             " %-5.4f %-5.4f",
             loss_ratio,
 	    ooo_ratio);
 #endif
-
-    pr = snprintf(buf, sizeof buf, "%6.4f", loss_ratio);
-    fprintf(out, " %s", (*buf == '0') ? (buf + 1) : buf);
-
-    pr = snprintf(buf, sizeof buf, "%6.4f", ooo_ratio);
-    fprintf(out, " %s", (*buf == '0') ? (buf + 1) : buf);
+    
+    dump_ratio(out, loss_ratio);
+    dump_ratio(out, ooo_ratio);
   }
 
   if (nepim_global.udp_accumulative_loss)
@@ -167,14 +239,25 @@ void nepim_slot_stat(FILE *out, struct timeval now,
 
   fprintf(out, "\n");
 
+  if (report_min_max) {
+    fprintf(out, "%3d %3d %3d %4s %5ld",
+	    sd, local_slot, remote_slot,
+	    NEPIM_LABEL_MIN, ts);
+    show_rates_line(out, min, 1 /* udp=true */);
+    fprintf(out, "%3d %3d %3d %4s %5ld",
+	    sd, local_slot, remote_slot,
+	    NEPIM_LABEL_MAX, ts);
+    show_rates_line(out, max, 1 /* udp=true */);
+  }
+
   /* otherwise server won't output stats if out is redirected */
   fflush(out);
 }
 
-void report_broken_pipe_stat_at(FILE *out, const nepim_pipe_t *pipe,
+void report_broken_pipe_stat_at(FILE *out, nepim_pipe_t *pipe,
 				struct timeval now)
 {
-  const nepim_session_t *session = &pipe->session;
+  nepim_session_t *session = &pipe->session;
   float elapsed_sec;
   float elapsed_usec;
   float elapsed;
@@ -194,10 +277,13 @@ void report_broken_pipe_stat_at(FILE *out, const nepim_pipe_t *pipe,
                   session->tv_start.tv_sec,
                   session->test_duration,
                   session->total_reads,
-                  session->total_writes);
+                  session->total_writes,
+		  &session->min,
+		  &session->max,
+		  1 /* report_min_max = true */);
 }
 
-void report_broken_pipe_stat(FILE *out, const nepim_pipe_t *pipe)
+void report_broken_pipe_stat(FILE *out, nepim_pipe_t *pipe)
 {
   struct timeval now;
   int result;
@@ -211,7 +297,7 @@ void report_broken_pipe_stat(FILE *out, const nepim_pipe_t *pipe)
 void report_broken_slot_stat_at(FILE *out, nepim_slot_t *slot,
 				struct timeval now)
 {
-  const nepim_session_t *session = &slot->session;
+  nepim_session_t *session = &slot->session;
   float elapsed_sec;
   float elapsed_usec;
   float elapsed;
@@ -240,7 +326,10 @@ void report_broken_slot_stat_at(FILE *out, nepim_slot_t *slot,
 		  slot->seq_highest_recv,
                   slot->total_pkt_lost,
                   slot->total_pkt_ooo,
-		  slot->total_pkt_lost);
+		  slot->total_pkt_lost,
+		  &session->min,
+		  &session->max,
+		  1 /* report_min_max = true */);
 }
 
 void report_broken_slot_stat(FILE *out, nepim_slot_t *slot)
