@@ -18,7 +18,7 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: greet.c,v 1.20 2007/03/23 12:40:05 evertonm Exp $ */
+/* $Id: greet.c,v 1.21 2007/10/18 21:51:43 evertonm Exp $ */
 
 #include <stdlib.h>
 #include <stdio.h>
@@ -51,6 +51,7 @@ const char *GREET_SWEEP_RANDOM      = "sweep_random=";
 const char *GREET_SWEEP_STEP        = "sweep_step=";
 const char *GREET_WRITE_FLOOR       = "write_floor=";
 const char *GREET_WRITE_CEIL        = "write_ceil=";
+const char *GREET_PARTIAL_MINMAX    = "partial_minmax=";
 const char *GREET_PASSWORD          = "password=";
 
 #define NEPIM_GREET_PARSE_OK     (0)
@@ -79,6 +80,7 @@ int nepim_write_greetings(const nepim_greet_t *opt, char *buf, int buf_size)
 		" %s0x%08x %s%d %s%d %s0x%02x %s%d"
 		" %s%d %s%d %s%d"
 		" %s%d %s%d %s%d %s%d"
+		" %s%d"
 		" %s%s\n", 
                 GREET_SERVER_SEND,       opt->must_send,
                 GREET_BIT_RATE,          opt->bit_rate,
@@ -102,8 +104,13 @@ int nepim_write_greetings(const nepim_greet_t *opt, char *buf, int buf_size)
 		GREET_SWEEP_STEP,        opt->sweep_step,
 		GREET_WRITE_FLOOR,       opt->write_floor,
 		GREET_WRITE_CEIL,        opt->write_ceil,
+		GREET_PARTIAL_MINMAX,    opt->report_partial_min_max,
                 GREET_PASSWORD,          opt->password_buf);
 
+#if 1
+  fprintf(stderr, "DEBUG [%s]\n", buf);
+#endif
+
   if (pr < 1)
     return NEPIM_GREET_WRITE_IO;
   if (pr >= buf_size)
@@ -145,6 +152,7 @@ int nepim_parse_greetings(nepim_greet_t *opt, int is_tcp,
   const int GREET_SWEEP_STEP_LEN        = strlen(GREET_SWEEP_STEP);
   const int GREET_WRITE_FLOOR_LEN       = strlen(GREET_WRITE_FLOOR);
   const int GREET_WRITE_CEIL_LEN        = strlen(GREET_WRITE_CEIL);
+  const int GREET_PARTIAL_MINMAX_LEN    = strlen(GREET_PARTIAL_MINMAX);
   const int GREET_PASSWORD_LEN          = strlen(GREET_PASSWORD);
 
   int       server_send       = -2;
@@ -169,6 +177,7 @@ int nepim_parse_greetings(nepim_greet_t *opt, int is_tcp,
   int       sweep_step        = -55555; /* something obviously wrong (-2 is too sane) */
   int       write_floor       = -2;
   int       write_ceil        = -2;
+  int       partial_minmax    = -2;
 
   assert(opt->password_buf);
   assert(opt->password_buf_size > 0);
@@ -308,6 +317,11 @@ int nepim_parse_greetings(nepim_greet_t *opt, int is_tcp,
       continue;
     }
 
+    if (!strncmp(tok, GREET_PARTIAL_MINMAX, GREET_PARTIAL_MINMAX_LEN)) {
+      partial_minmax = atoi(tok + GREET_PARTIAL_MINMAX_LEN);
+      continue;
+    }
+
     if (!strncmp(tok, GREET_PASSWORD, GREET_PASSWORD_LEN)) {
       const char *tmp_past_end = tmp + sizeof(tmp);
       const char *pass;
@@ -367,28 +381,29 @@ int nepim_parse_greetings(nepim_greet_t *opt, int is_tcp,
     }
   }
 
-  opt->must_send            = server_send;
-  opt->bit_rate             = bit_rate;
-  opt->pkt_rate             = pkt_rate;
-  opt->stat_interval        = stat_interval;
-  opt->test_duration        = test_duration;
-  opt->write_delay          = write_delay;
-  opt->keepalive_must_send  = server_ka_send;
-  opt->keepalive_require    = server_ka_require;
-  opt->keepalive_timeout    = server_ka_timeout;
-  opt->keepalive_send_delay = server_ka_delay;
-  opt->seed                 = seed;
-  opt->verify_data          = verify_data;
-  opt->random_fill          = random_fill;
-  opt->fill_byte            = (unsigned char) fill_byte;
-  opt->pause_duration       = pause_duration;
-  opt->socket_keepalive     = socket_keepalive;
-  opt->nagle                = nagle;
-  opt->overhead             = overhead;
-  opt->sweep_random         = sweep_random;
-  opt->sweep_step           = sweep_step;
-  opt->write_floor          = write_floor;
-  opt->write_ceil           = write_ceil;
+  opt->must_send              = server_send;
+  opt->bit_rate               = bit_rate;
+  opt->pkt_rate               = pkt_rate;
+  opt->stat_interval          = stat_interval;
+  opt->test_duration          = test_duration;
+  opt->write_delay            = write_delay;
+  opt->keepalive_must_send    = server_ka_send;
+  opt->keepalive_require      = server_ka_require;
+  opt->keepalive_timeout      = server_ka_timeout;
+  opt->keepalive_send_delay   = server_ka_delay;
+  opt->seed                   = seed;
+  opt->verify_data            = verify_data;
+  opt->random_fill            = random_fill;
+  opt->fill_byte              = (unsigned char) fill_byte;
+  opt->pause_duration         = pause_duration;
+  opt->socket_keepalive       = socket_keepalive;
+  opt->nagle                  = nagle;
+  opt->overhead               = overhead;
+  opt->sweep_random           = sweep_random;
+  opt->sweep_step             = sweep_step;
+  opt->write_floor            = write_floor;
+  opt->write_ceil             = write_ceil;
+  opt->report_partial_min_max = (partial_minmax == -2) ? 0 : partial_minmax;
 
   return NEPIM_GREET_PARSE_OK;
 }
