@@ -18,7 +18,7 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: server.c,v 1.80 2007/08/30 15:08:00 evertonm Exp $ */
+/* $Id: server.c,v 1.81 2007/10/18 21:51:44 evertonm Exp $ */
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -369,7 +369,10 @@ static void *on_tcp_duration(oop_source *src, struct timeval tv, void *user)
                   session->tv_start.tv_sec,
                   session->test_duration,
                   session->total_reads,
-                  session->total_writes);
+                  session->total_writes,
+		  &session->min,
+		  &session->max,
+		  1 /* report_min_max = true */);
 
   session->byte_total_recv = 0;
   session->byte_total_sent = 0;
@@ -397,7 +400,10 @@ static void *on_tcp_interval(oop_source *src, struct timeval tv, void *user)
                   session->tv_start.tv_sec,
                   session->test_duration,
                   session->interval_reads,
-                  session->interval_writes);
+                  session->interval_writes,
+		  &session->min,
+		  &session->max,
+		  session->report_partial_min_max);
 
   session->byte_interval_recv = 0;
   session->byte_interval_sent = 0;
@@ -433,7 +439,7 @@ static int parse_greetings(int sd,
           "seed=0x%08x verify_data=%d random_fill=%d fill_byte=0x%02x pause_duration=%d "
           "sock_ka=%d nagle=%d overhead=%d "
 	  "sweep_random=%d sweep_step=%d write_floor=%d write_ceil=%d "
-	  "password=%s\n", 
+	  "p_minmax=%d password=%s\n", 
           sd, opt.must_send, opt.bit_rate, opt.pkt_rate,
           opt.stat_interval, opt.test_duration, 
           opt.write_delay, opt.keepalive_must_send,
@@ -442,6 +448,7 @@ static int parse_greetings(int sd,
           opt.verify_data, opt.random_fill, opt.fill_byte, opt.pause_duration,
 	  opt.socket_keepalive, opt.nagle, opt.overhead,
 	  opt.sweep_random, opt.sweep_step, opt.write_floor, opt.write_ceil,
+	  opt.report_partial_min_max,
           password_buf);
 
   nepim_conf_write_sweep_auto(0 /* udp=false */,
