@@ -18,7 +18,7 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: udp_client.c,v 1.83 2007/08/31 12:03:44 evertonm Exp $ */
+/* $Id: udp_client.c,v 1.84 2007/10/18 21:51:44 evertonm Exp $ */
 
 #include <stdio.h>
 #include <string.h>
@@ -427,6 +427,7 @@ static int slot_greet_write(nepim_slot_t *slot)
   opt.sweep_step              = nepim_global.sweep_step;
   opt.write_floor             = nepim_global.server_write_floor;
   opt.write_ceil              = nepim_global.server_write_ceil;
+  opt.report_partial_min_max  = nepim_global.report_partial_min_max;
 
   if (nepim_global.password) {
     opt.password_buf      = (char *) nepim_global.password;
@@ -510,7 +511,10 @@ static void *on_udp_interval(oop_source *src, struct timeval tv, void *user)
 		  slot->seq_highest_recv - slot->interval_last_highest_seq,
                   slot->interval_pkt_lost,
                   slot->interval_pkt_ooo,
-		  slot->total_pkt_lost);
+		  slot->total_pkt_lost,
+		  &session->min,
+		  &session->max,
+		  session->report_partial_min_max);
 
   session->byte_interval_recv = 0;
   session->byte_interval_sent = 0;
@@ -569,7 +573,10 @@ static void *on_udp_duration(oop_source *src, struct timeval tv, void *user)
 		  slot->seq_highest_recv,
                   slot->total_pkt_lost,
                   slot->total_pkt_ooo,
-		  slot->total_pkt_lost);
+		  slot->total_pkt_lost,
+		  &session->min,
+		  &session->max,
+		  1 /* report_min_max = true */);
 
   session->byte_total_recv = 0;
   session->byte_total_sent = 0;
@@ -1446,6 +1453,7 @@ static void parse_hosts(const char *host_list)
       opt.sweep_step              = nepim_global.sweep_step;
       opt.write_floor             = nepim_global.write_floor;
       opt.write_ceil              = nepim_global.write_ceil;
+      opt.report_partial_min_max  = nepim_global.report_partial_min_max;
       
       /* create UDP slots */
       for (i = 0; i < nepim_global.pipes; ++i) {
